@@ -1,4 +1,4 @@
-from Quartz import *
+import Quartz
 import Utilities
 
 import sys
@@ -54,14 +54,10 @@ def createFunctionForRGB(evaluationFunction):
     )
 
     # Dimension of domain is 1 and dimension of range is 4.
-    function = CGFunctionCreate(None, 1, domain, 4, range,
-            (
-                evaluationFunction,
-                None
-            ))
+    function = Quartz.CGFunctionCreate(None, 1, domain, 4, range, evaluationFunction)
 
     if function is None:
-        print >>sys.stderr, "Couldn't create the CGFunction!"
+        print("Couldn't create the CGFunction!")
         return None
 
     return function
@@ -76,13 +72,13 @@ def doSimpleAxialShading(context):
     # Start the shading at the point (20,20) and
     # end it at (420,20). The axis of the shading
     # is a line from (20,20) to (420,20).
-    startPoint = CGPoint(x = 20, y = 20)
-    endPoint = CGPoint(x = 420, y = 20)
+    startPoint = Quartz.CGPoint(x = 20, y = 20)
+    endPoint = Quartz.CGPoint(x = 420, y = 20)
 
     # Don't extend this shading.
     extendStart = extendEnd = False
 
-    shading = CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
+    shading = Quartz.CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
                             startPoint, endPoint,
                             axialFunction,
                             extendStart, extendEnd)
@@ -90,13 +86,13 @@ def doSimpleAxialShading(context):
     # is done with the function so it should release it.
     del axialFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
     # Draw the shading. This paints the shading to
     # the destination context, clipped by the
     # current clipping area.
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
 
 def RedGreenRampEvaluate(info, input, output):
     # The domain of this function is 0 - 1. For an input value of 0
@@ -127,7 +123,7 @@ def RedGreenRampEvaluate(info, input, output):
     )
 
 def doExampleAxialShading(context):
-    rect = CGRectMake(0, 0, 240, 240)
+    rect = Quartz.CGRectMake(0, 0, 240, 240)
 
     # This shading paints colors in the calibrated Generic RGB
     # color space so it needs a function that evaluates 1 in to 4 out.
@@ -138,47 +134,47 @@ def doExampleAxialShading(context):
     # Start the shading at the point (20,20) and
     # end it at (220,220). The axis of the shading
     # is a diagonal line from (20,20) to (220,220).
-    startPoint = CGPoint(x = 20, y = 20)
-    endPoint = CGPoint(x = 220, y = 220)
+    startPoint = Quartz.CGPoint(x = 20, y = 20)
+    endPoint = Quartz.CGPoint(x = 220, y = 220)
 
     # Don't extend this shading.
     extendStart = extendEnd = False
-    shading = CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
+    shading = Quartz.CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
                             startPoint, endPoint,
                             redGreenFunction,
                             extendStart, extendEnd)
 
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
     # Position for the first portion of the drawing.
-    CGContextTranslateCTM(context, 40, 260)
+    Quartz.CGContextTranslateCTM(context, 40, 260)
 
     # Stroke a black rectangle that will frame the shading.
-    CGContextSetLineWidth(context, 2)
-    CGContextSetStrokeColorWithColor(context, Utilities.getRGBOpaqueBlackColor())
-    CGContextStrokeRect(context, rect)
+    Quartz.CGContextSetLineWidth(context, 2)
+    Quartz.CGContextSetStrokeColorWithColor(context, Utilities.getRGBOpaqueBlackColor())
+    Quartz.CGContextStrokeRect(context, rect)
 
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
         # Clip to the rectangle that was just stroked.
-        CGContextClipToRect(context, rect)
+        Quartz.CGContextClipToRect(context, rect)
         # Draw the shading. This paints the shading to
         # the destination context, clipped to rect.
-        CGContextDrawShading(context, shading)
+        Quartz.CGContextDrawShading(context, shading)
         # Release the shading once the code is finished with it.
         del shading
         # Restore the graphics state so that the rectangular
         # clip is no longer present.
-    CGContextRestoreGState(context)
+    Quartz.CGContextRestoreGState(context)
 
     # Prepare for the next shading.
-    CGContextTranslateCTM(context, 0, -250)
+    Quartz.CGContextTranslateCTM(context, 0, -250)
 
     # Extend this shading.
     extendStart = extendEnd = True
-    shading = CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
+    shading = Quartz.CGShadingCreateAxial(Utilities.getTheCalibratedRGBColorSpace(),
                             startPoint, endPoint,
                             redGreenFunction,
                             extendStart, extendEnd)
@@ -186,39 +182,39 @@ def doExampleAxialShading(context):
     # is done with the function so it should release it.
     del redGreenFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
     # Stroke with the current stroke color.
-    CGContextStrokeRect(context, rect)
+    Quartz.CGContextStrokeRect(context, rect)
 
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
-        CGContextClipToRect(context, rect)
+        Quartz.CGContextClipToRect(context, rect)
         # Draw the shading. This paints the shading to
         # the destination context, clipped to rect.
-        CGContextDrawShading(context, shading)
-    CGContextRestoreGState(context)
+        Quartz.CGContextDrawShading(context, shading)
+    Quartz.CGContextRestoreGState(context)
 
     # Now paint some text with a shading.
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
-        CGContextTranslateCTM(context, 260, 0)
-        CGContextSetTextMatrix(context, CGAffineTransformIdentity)
+        Quartz.CGContextTranslateCTM(context, 260, 0)
+        Quartz.CGContextSetTextMatrix(context, Quartz.CGAffineTransformIdentity)
 
         # Set the font with the PostScript name "Times-Roman", at
         # 80 points, with the MacRoman encoding.
-        CGContextSelectFont(context, "Times-Roman", 80,
-                                            kCGEncodingMacRoman)
+        Quartz.CGContextSelectFont(context, b"Times-Roman", 80,
+                                            Quartz.kCGEncodingMacRoman)
 
         # Rotate so that the text characters are rotated
         # relative to the page.
-        CGContextRotateCTM(context, Utilities.DEGREES_TO_RADIANS(45))
+        Quartz.CGContextRotateCTM(context, Utilities.DEGREES_TO_RADIANS(45))
         # Set the text drawing mode to clip so that
         # the characters in the string are intersected with
         # the clipping area.
-        CGContextSetTextDrawingMode(context, kCGTextClip)
-        CGContextShowTextAtPoint(context, 30, 0, "Shading", 7)
+        Quartz.CGContextSetTextDrawingMode(context, Quartz.kCGTextClip)
+        Quartz.CGContextShowTextAtPoint(context, 30, 0, b"Shading", 7)
 
         # At this point nothing has been painted; the
         # glyphs in the word "Shading" have been intersected
@@ -227,13 +223,13 @@ def doExampleAxialShading(context):
 
         # Rotate the coordinate system back so that the
         # shading is not rotated relative to the page.
-        CGContextRotateCTM(context, Utilities.DEGREES_TO_RADIANS(-45))
+        Quartz.CGContextRotateCTM(context, Utilities.DEGREES_TO_RADIANS(-45))
 
         # Draw the shading, painting the shading
         # to the destination context, clipped by the glyphs.
-        CGContextDrawShading(context, shading)
+        Quartz.CGContextDrawShading(context, shading)
 
-    CGContextRestoreGState(context)
+    Quartz.CGContextRestoreGState(context)
     # Release the shading once the code is finished with it.
     del shading
 
@@ -303,11 +299,11 @@ def createFunctionWithStartEndColorRamp(startColor, endColor):
     )
 
     # Pass startEndColorP as the info parameter.
-    function = CGFunctionCreate(startEndColorP, 1, domain, 4,
-                        range, (StartColorEndColorEvaluate, None))
+    function = Quartz.CGFunctionCreate(startEndColorP, 1, domain, 4,
+                        range, StartColorEndColorEvaluate)
 
     if function is None:
-        print >>sys.stderr, "Couldn't create the CGFunction!"
+        print("Couldn't create the CGFunction!")
         return None
 
     return function
@@ -323,10 +319,10 @@ def doSimpleRadialShading(context):
     if redYellowFunction is None:
         return
 
-    CGContextTranslateCTM(context, 120, 120)
+    Quartz.CGContextTranslateCTM(context, 120, 120)
 
     # Circles whose origin is the same.
-    circleACenter = CGPoint(x = 0, y = 0)
+    circleACenter = Quartz.CGPoint(x = 0, y = 0)
     circleBCenter = circleACenter
 
     # The starting circle is inside the ending circle.
@@ -335,7 +331,7 @@ def doSimpleRadialShading(context):
 
     #  Don't extend the shading.
     extendStart = extendEnd = False
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                 Utilities.getTheCalibratedRGBColorSpace(),
                 circleACenter, circleARadius,
                 circleBCenter, circleBRadius,
@@ -344,9 +340,9 @@ def doSimpleRadialShading(context):
 
     del redYellowFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
 
 def doExampleRadialShadings(context):
     magenta   = [ 1,    0, 1    ] # Pure magenta.
@@ -357,14 +353,14 @@ def doExampleRadialShadings(context):
     blue      = [ 0,    0, 1    ]
     redgreen  = [ 0.66, 1, 0.04 ] # A red-green shade.
 
-    CGContextTranslateCTM(context, 120, 550)
+    Quartz.CGContextTranslateCTM(context, 120, 550)
 
     # This function describes a color ramp where the starting color
     # is a full magenta, the ending color is 30% magenta.
     magentaFunction = createFunctionWithStartEndColorRamp(
                             magenta, magenta30)
     if magentaFunction is None:
-        print >>sys.stderr, "Couldn't create the magenta function!"
+        print("Couldn't create the magenta function!")
         return
 
     # Shading 1. Circle A is completely inside circle B but with
@@ -372,9 +368,9 @@ def doExampleRadialShadings(context):
     # a point source.
 
     # The center of circle A is offset from the origin.
-    circleACenter = CGPoint(x=30, y=40)
+    circleACenter = Quartz.CGPoint(x=30, y=40)
     # The center of circle B is at the origin.
-    circleBCenter = CGPoint(x=0, y=0)
+    circleBCenter = Quartz.CGPoint(x=0, y=0)
 
     # A radius of zero produces a point source.
     circleARadius = 0
@@ -382,7 +378,7 @@ def doExampleRadialShadings(context):
 
     # Don't extend the shading.
     extendStart = extendEnd = False
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                 Utilities.getTheCalibratedRGBColorSpace(),
                 circleACenter, circleARadius,
                 circleBCenter, circleBRadius,
@@ -391,10 +387,10 @@ def doExampleRadialShadings(context):
     # Finished with the magenta function so release it.
     del magentaFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
     # Finished with the shading so release it.
     del shading
 
@@ -405,7 +401,7 @@ def doExampleRadialShadings(context):
     redGreenFunction = createFunctionWithStartEndColorRamp(
                             red, green)
     if redGreenFunction is None:
-        print >>sys.stderr, "Couldn't create the red-Green function!"
+        print("Couldn't create the red-Green function!")
         return
 
     circleACenter.x = 55
@@ -420,7 +416,7 @@ def doExampleRadialShadings(context):
     # Extend the end point of this shading.
     extendStart = False
     extendEnd = True
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
@@ -429,31 +425,31 @@ def doExampleRadialShadings(context):
     # Finished with this function so release it.
     del redGreenFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
     # Set a clipping area to bound the extend. This code
     # sets a clipping area that corresponds to a circular
     # wedge. The starting circle is inside the clipping
     # area and the ending circle is outside.
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
-        CGContextTranslateCTM(context, 250, 0)
-        CGContextBeginPath(context)
-        CGContextMoveToPoint(context, 25, 0)
-        CGContextAddArc(context,
+        Quartz.CGContextTranslateCTM(context, 250, 0)
+        Quartz.CGContextBeginPath(context)
+        Quartz.CGContextMoveToPoint(context, 25, 0)
+        Quartz.CGContextAddArc(context,
                         25, 0, 130,
                         Utilities.DEGREES_TO_RADIANS(30),
                         Utilities.DEGREES_TO_RADIANS(-30),
                         0)
-        CGContextClip(context)
+        Quartz.CGContextClip(context)
         # Paint the shading.
-        CGContextDrawShading(context, shading)
+        Quartz.CGContextDrawShading(context, shading)
         # Finished with the shading so release it.
         del shading
-    CGContextRestoreGState(context)
+    Quartz.CGContextRestoreGState(context)
 
-    CGContextTranslateCTM(context, -40, -250)
+    Quartz.CGContextTranslateCTM(context, -40, -250)
 
     # Shading 3. The starting circle is completely outside
     # the ending circle, no extension. The circles
@@ -472,20 +468,20 @@ def doExampleRadialShadings(context):
     redBlackFunction = createFunctionWithStartEndColorRamp(
                             red, black)
     if redBlackFunction is None:
-        print >>sys.stderr, "Couldn't create the red-black function!"
+        print("Couldn't create the red-black function!")
         return
 
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
                     redBlackFunction,
                     extendStart, extendEnd)
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
     # Finished with the shading so release it.
     del shading
 
@@ -501,7 +497,7 @@ def doExampleRadialShadings(context):
 
     # Extend at the start and end.
     extendStart = extendEnd = True
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                 Utilities.getTheCalibratedRGBColorSpace(),
                 circleACenter, circleARadius,
                 circleBCenter, circleBRadius,
@@ -510,30 +506,30 @@ def doExampleRadialShadings(context):
     # Finished with this function so release it.
     del redBlackFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
-        CGContextTranslateCTM(context, 270, 0)
+        Quartz.CGContextTranslateCTM(context, 270, 0)
         # Clip to an elliptical path so the shading
         # does not extend to infinity at the larger end.
-        CGContextBeginPath(context)
+        Quartz.CGContextBeginPath(context)
         Utilities.myCGContextAddEllipseInRect(context,
-                        CGRectMake(-200, -200, 450, 400))
-        CGContextClip(context)
-        CGContextDrawShading(context, shading)
+                        Quartz.CGRectMake(-200, -200, 450, 400))
+        Quartz.CGContextClip(context)
+        Quartz.CGContextDrawShading(context, shading)
         # Finished with the shading so release it.
         del shading
-    CGContextRestoreGState(context)
+    Quartz.CGContextRestoreGState(context)
 
-    CGContextTranslateCTM(context, 30, -200)
+    Quartz.CGContextTranslateCTM(context, 30, -200)
 
     # The starting color is blue, the ending color is a red-green color.
     blueGreenFunction = createFunctionWithStartEndColorRamp(
                             blue, redgreen)
     if blueGreenFunction is None:
-        print >>sys.stderr, "Couldn't create the blue-Green function!"
+        print("Couldn't create the blue-Green function!")
         return
 
     # Shading 5. The circles partially overlap and have
@@ -547,28 +543,28 @@ def doExampleRadialShadings(context):
     circleBRadius = 45
 
     extendStart = extendEnd = False
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
                     blueGreenFunction,
                     extendStart, extendEnd)
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
     # Finished with the shading so release it.
     del shading
 
-    CGContextTranslateCTM(context, 200, 0)
+    Quartz.CGContextTranslateCTM(context, 200, 0)
 
     # Shading 6. The circles partially overlap and have
     # different radii with the larger circle at the end.
 
     circleARadius = 45
     circleBRadius = 75
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
@@ -577,10 +573,10 @@ def doExampleRadialShadings(context):
     # Finished with this function so release it.
     del blueGreenFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
 
 def doEllipseShading(context):
     black = [ 0, 0, 0 ]
@@ -591,10 +587,10 @@ def doEllipseShading(context):
     redBlackFunction = createFunctionWithStartEndColorRamp(
                             red, black)
     if redBlackFunction is None:
-        print >>sys.stderr, "Couldn't create the red-black function!"
+        print("Couldn't create the red-black function!")
         return
 
-    CGContextTranslateCTM(context, 100, 300)
+    Quartz.CGContextTranslateCTM(context, 100, 300)
     # Shading 1.
     #   To obtain an elliptical shading requires that user space
     #   at the time the shading is painted is transformed so that
@@ -604,18 +600,18 @@ def doEllipseShading(context):
     #   the ellipses.
 
     # Compute the transform needed to create the rotated ellipses.
-    t = CGAffineTransformMakeRotation(Utilities.DEGREES_TO_RADIANS(45))
-    t = CGAffineTransformScale(t, 1, 2)
+    t = Quartz.CGAffineTransformMakeRotation(Utilities.DEGREES_TO_RADIANS(45))
+    t = Quartz.CGAffineTransformScale(t, 1, 2)
 
-    circleACenter = CGPoint(x=0, y=0)
-    circleBCenter = CGPoint(x=circleACenter.x + 144, y=circleACenter.y)
+    circleACenter = Quartz.CGPoint(x=0, y=0)
+    circleBCenter = Quartz.CGPoint(x=circleACenter.x + 144, y=circleACenter.y)
     circleARadius = 45
     circleBRadius = 45
 
     # Don't extend this shading.
     extendStart = extendEnd = False
 
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
@@ -624,23 +620,23 @@ def doEllipseShading(context):
     if shading is None:
         # Couldn't create the shading so release
         # the function before returning.
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
-    CGContextSaveGState(context)
+    Quartz.CGContextSaveGState(context)
     if 1:
         # Transform coordinates for the drawing of the shading.
         # This transform produces the rotated elliptical shading.
         # This produces the left shading in the figure, the
         # one where both the ellipses and the shading are
         # rotated relative to default user space.
-        CGContextConcatCTM(context, t)
+        Quartz.CGContextConcatCTM(context, t)
 
-        CGContextDrawShading(context, shading)
+        Quartz.CGContextDrawShading(context, shading)
         del shading
-    CGContextRestoreGState(context)
+    Quartz.CGContextRestoreGState(context)
 
-    CGContextTranslateCTM(context, 300, 10)
+    Quartz.CGContextTranslateCTM(context, 300, 10)
 
 
     # Shading 2.
@@ -672,15 +668,15 @@ def doEllipseShading(context):
     #    This means that we can calculate the point P
     #    by computing P' x Inverse(t).
 
-    inverseT = CGAffineTransformInvert(t)
+    inverseT = Quartz.CGAffineTransformInvert(t)
     # Now the code can transform the coordinates through the
     # inverse transform to compute the new coordinates. These
     # coordinates, when transformed with the transform t,
     # produce the original coordinate.
-    circleACenter = CGPointApplyAffineTransform(circleACenter, inverseT)
-    circleBCenter = CGPointApplyAffineTransform(circleBCenter, inverseT)
+    circleACenter = Quartz.CGPointApplyAffineTransform(circleACenter, inverseT)
+    circleBCenter = Quartz.CGPointApplyAffineTransform(circleBCenter, inverseT)
 
-    shading = CGShadingCreateRadial(
+    shading = Quartz.CGShadingCreateRadial(
                     Utilities.getTheCalibratedRGBColorSpace(),
                     circleACenter, circleARadius,
                     circleBCenter, circleBRadius,
@@ -689,11 +685,11 @@ def doEllipseShading(context):
     # The code is finished with the function so release it.
     del redBlackFunction
     if shading is None:
-        print >>sys.stderr, "Couldn't create the shading!"
+        print("Couldn't create the shading!")
         return
 
     # Transform coordinates for the drawing of the shading.
     # This transform produces the rotated elliptical shading.
-    CGContextConcatCTM(context, t)
+    Quartz.CGContextConcatCTM(context, t)
 
-    CGContextDrawShading(context, shading)
+    Quartz.CGContextDrawShading(context, shading)
