@@ -7,26 +7,6 @@
 
 #import <ApplicationServices/ApplicationServices.h>
 
-#if PyObjC_BUILD_RELEASE >= 1006
-#  if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_6
-
-/* 
- * Implementation of poor-mans weak linking for a 10.6+ symbol, needed
- * to be able to use a binary created on OSX 10.8 on a 10.5 system.
- *
- * XXX: The same mechanism should be used for the other functions wrapped
- *      in this file.
- */
-#include <dlfcn.h>
-static CGContextRef (*ptr_CGBitmapContextCreateWithData)(
-		   void *data, size_t width, size_t height, size_t bitsPerComponent, size_t bytesPerRow,
-		  CGColorSpaceRef space, CGBitmapInfo bitmapInfo, CGBitmapContextReleaseDataCallback releaseCallback,
-		   void *releaseInfo);
-#  else
-#    define ptr_CGBitmapContextCreateWithData CGBitmapContextCreateWithData
-#  endif
-#endif
- 
 
 
 #if PyObjC_BUILD_RELEASE >= 1005
@@ -382,6 +362,7 @@ m_releasecallback(void* releaseInfo, void* data)
 
 }
 
+WEAK_LINKED_NAME_10_6(CGBitmapContextCreateWithData)
 static PyObject*
 m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)), 
 		PyObject* args)
@@ -460,7 +441,7 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
 
 	CGContextRef ctx = NULL;
 	PyObjC_DURING
-		ctx = ptr_CGBitmapContextCreateWithData(data, width, height, bitsPerComponent, bytesPerRow, colorSpace, bitmapInfo, m_releasecallback, releaseInfo);
+		ctx = USE_10_6(CGBitmapContextCreateWithData)(data, width, height, bitsPerComponent, bytesPerRow, colorSpace, bitmapInfo, m_releasecallback, releaseInfo);
 
 	PyObjC_HANDLER
 		ctx = NULL;
@@ -571,16 +552,7 @@ PyObjC_MODULE_INIT(_coregraphics)
 
 
 #if (PyObjC_BUILD_RELEASE >= 1006) && (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_6)
-	{
-		void* dl = dlopen(NULL, RTLD_GLOBAL);
-		ptr_CGBitmapContextCreateWithData = dlsym(dl, "CGBitmapContextCreateWithData");
-		if (ptr_CGBitmapContextCreateWithData == NULL) {
-			if (PyDict_DelItemString(d, "CGBitmapContextCreateWithData") < 0) {
-				PyObjC_INITERROR();
-			}
-		}
-		/* Don't call dlclose */
-	}
+	CHECK_WEAK_LINK_10_6(m, CGBitmapContextCreateWithData);
 #endif
 
 	PyObjC_INITDONE();
