@@ -1,6 +1,11 @@
 from Quartz import *
 from PyObjCTools.TestSupport import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 
 class TestCAShapeLayer (TestCase):
     @min_os_level('10.6')
@@ -9,7 +14,7 @@ class TestCAShapeLayer (TestCase):
         self.assertIsInstance(kCAFillRuleEvenOdd, unicode)
         self.assertIsInstance(kCALineJoinMiter, unicode)
         self.assertIsInstance(kCALineJoinRound, unicode)
-        self.assertIsInstance(kCALineJoinRound, unicode)
+        self.assertIsInstance(kCALineJoinBevel, unicode)
         self.assertIsInstance(kCALineCapButt, unicode)
         self.assertIsInstance(kCALineCapRound, unicode)
         self.assertIsInstance(kCALineCapSquare, unicode)
